@@ -7,7 +7,6 @@ use 5.006;
 use Carp;
 use Cwd qw( cwd );
 use IO::Handle;
-use IPC::Open3 qw( open3 );
 use Scalar::Util qw( blessed );
 use File::Spec;
 use Config;
@@ -143,7 +142,7 @@ sub new {
 }
 
 sub final_output {
-    my ($self) = @_;
+    my ($self, @cb) = @_;
 
     # get output / errput
     my ( $stdout, $stderr ) = @{$self}{qw(stdout stderr)};
@@ -166,6 +165,11 @@ sub final_output {
     # something else's wrong
     if ( @errput && !$self->options->{quiet} ) { carp join "\n", @errput; }
 
+    # process the output with the optional callbacks
+    for my $cb (@cb) {
+        @output = map $cb->($_), @output;
+    }
+
     # return the output
     return wantarray ? @output : join "\n", @output;
 }
@@ -293,7 +297,7 @@ number of attributes defined (see below).
 Close all pipes to the child process, and collects exit status, etc.
 and defines a number of attributes (see below).
 
-=head2 final_output()
+=head2 final_output( @callbacks )
 
 Collect all the output, and terminate the command.
 
@@ -302,6 +306,10 @@ or as a list of lines in list context. Also accepts a hashref of options.
 
 Lines are automatically C<chomp>ed.
 
+If C<@callbacks> is provided, the code references will be applied
+successively to each line of output. The line being processed is in C<$_>,
+but the coderef must still return the result string.
+
 If the Git command printed anything on stderr, it will be printed as
 warnings. If the git sub-process exited with status C<128> (fatal error),
 or C<129> (usage message), it will C<die()>.
